@@ -34,7 +34,7 @@
 ;; mode hooks instead of calling `undo-fu-session-global-mode'.
 ;; The following example enables this for org-mode:
 ;;
-;;   (add-hook 'org-mode-hook (lambda () (undo-fu-session-mode))
+;;   (add-hook 'org-mode-hook (lambda () (undo-fu-session-mode)))
 ;;
 
 ;;; Code:
@@ -209,7 +209,7 @@ ignoring all branches that aren't included in the current undo state."
                ;; Collapse all redo branches (giving the same results as if running `undo-only')
                (while (setq undo-list-next (gethash undo-list equiv-table))
                  (setq undo-list undo-list-next))
-               (and undo-list (not (eq t undo-list))))
+               (and undo-list (null (eq t undo-list))))
 
         ;; Pop all steps until the next boundary 'nil'.
         (let ((undo-elt t))
@@ -225,7 +225,7 @@ ignoring all branches that aren't included in the current undo state."
     ;; Note that we use 'nil' as this is what `buffer-undo-list' is set
     ;; to when there are no undo steps yet.
     (cond
-     ((and linear-list (not (equal (list nil) linear-list)))
+     ((and linear-list (null (equal (list nil) linear-list)))
       linear-list)
      (t
       nil))))
@@ -263,7 +263,7 @@ ignoring all branches that aren't included in the current undo state."
        ((eq value tree)
         (let* ((length (length tree))
                (vector (make-vector length nil)))
-          (dotimes (i (1- length))
+          (dotimes (i length)
             (aset vector i (undo-fu-session--walk-tree fn (aref tree i))))
           vector))
        (t
@@ -550,7 +550,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
     ".el")))
 
 (defun undo-fu-session--make-file-name (filename)
-  "Take the path FILENAME and return a name base on this."
+  "Take the path FILENAME and return a name based on this."
   (declare (important-return-value t))
   (let ((ext (undo-fu-session--file-name-ext)))
     (condition-case err
@@ -739,7 +739,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
     (condition-case err
         (undo-fu-session--save-impl)
       (error
-       (message "Undo-Fu-Session can not save undo data: %s" (error-message-string err)))))
+       (message "Undo-Fu-Session cannot save undo data: %s" (error-message-string err)))))
   ;; Important to return NIL, to show the file wasn't saved.
   nil)
 
@@ -833,7 +833,7 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
     (condition-case err
         (undo-fu-session--recover-impl)
       (error
-       (message "Undo-Fu-Session can not recover undo data: %s" (error-message-string err))))))
+       (message "Undo-Fu-Session cannot recover undo data: %s" (error-message-string err))))))
 
 
 ;; ---------------------------------------------------------------------------
@@ -901,12 +901,12 @@ Argument PENDING-LIST an `pending-undo-list' compatible list."
   (declare (important-return-value nil))
   (when (and
          ;; Not already enabled.
-         (not (bound-and-true-p undo-fu-session-mode))
+         (null (bound-and-true-p undo-fu-session-mode))
          ;; Not in the mini-buffer.
-         (not (minibufferp))
+         (null (minibufferp))
          ;; Not a special mode (package list, tabulated data ... etc)
          ;; Instead the buffer is likely derived from `text-mode' or `prog-mode'.
-         (not (derived-mode-p 'special-mode)))
+         (null (derived-mode-p 'special-mode)))
     (undo-fu-session-mode 1)))
 
 ;;;###autoload
